@@ -180,7 +180,7 @@ def omega_dimensionless_IPL(T: float, l: int, sigma: float, eps: float, phizero:
     eps : float
         the Lennard-Jones :math:`\\varepsilon_{cd}` parameter, divided by Boltzmann's constant
     phizero : float
-        the IPL :math:`\\phi_{0}` parameter
+        the IPL :math:`\\phi_{0}` parameter, divided by Boltzmann's constant
     beta : float
         the IPL :math:`\\beta` parameter
 
@@ -212,12 +212,12 @@ def omega_dimensionless_IPL(T: float, l: int, sigma: float, eps: float, phizero:
                       [-87.7036, 46.313, 227.146, 363.1807]])
         coeff = 1.04
         pows = np.array([2, 3, 4])
-        TT = np.log(vstar / 10)
+        TT = np.log(Tstar)
     else:
         raise KineticlibError('Cannot calculate the Omega^{(' + str(l) + ',' + str(l)
                               + ')} integral using the IPL potential')
-    Abig[:] = a[:, 0] + (a[:, 1] + a[:, 2] / np.log(vstar / 10) + a[:, 3] / ((np.log(vstar / 10)) ** 2)) /\
-              ((rstar * np.log(vstar / 10)) ** 2)
+    Abig[:] = a[:, 0] + (a[:, 1] + a[:, 2] / np.log(vstar / 10)
+                         + a[:, 3] / ((np.log(vstar / 10)) ** 2)) / ((rstar * np.log(vstar / 10)) ** 2)
     return (coeff + Abig[0] / (TT ** pows[0]) + Abig[1] / (TT ** pows[1]) + Abig[2] / (TT ** pows[2])) *\
            ((rstar * np.log(vstar / Tstar)) ** 2)
 
@@ -486,7 +486,7 @@ def omega_dimensionless_esa(T: float, l: int, r: int, beta: float, eps: float) -
         coeff_array[6, 1] = 2.842981 * (10 ** (-1))
         coeff_array[6, 2] = -1.874462 * (10 ** (-2))
     else:
-        raise KineticlibError('Cannot calculate the Omega^{(' + str(l) + ',' + str(l)
+        raise KineticlibError('Cannot calculate the Omega^{(' + str(l) + ',' + str(r)
                               + ')} integral using the ESA data')
     for i in range(7):
         a[i] = np.dot(coeff_array[i, :], beta_pow_array)
