@@ -35,7 +35,8 @@ def vt_rate(T: float, idata: np.ndarray, molecule: MoleculeSTS, i: int, delta: i
         The VT transition rate
 
     """
-    return raw_vt_rate(T, idata, molecule.vibr, molecule.vibr_zero, molecule.diss, i, delta)
+    return raw_vt_rate(T, idata[0], idata[4], idata[9], idata[10],
+                       molecule.vibr, molecule.vibr_zero, molecule.diss, i, delta)
 
 
 def vv_rate(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS, i: int, k: int, i_delta: int):
@@ -65,10 +66,11 @@ def vv_rate(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: Mole
         The VV transition rate
 
     """
-    return raw_vv_rate(T, idata, molecule1.vibr, molecule2.vibr, i, k, i_delta)
+    return raw_vv_rate(T, idata[0], idata[4], idata[9], idata[10], molecule1.vibr, molecule2.vibr, i, k, i_delta)
 
 
-def raw_vt_rate(T: float, idata: np.ndarray, molecule_vibr_array: np.ndarray, molecule_vibr_zero: float,
+def raw_vt_rate(T: float, mass: float, beta: float, vssc: float, vsso: float,
+                molecule_vibr_array: np.ndarray, molecule_vibr_zero: float,
                 molecule_diss: float, i: int, delta: int) -> float:
     """Calculates the VT transition rate using the FHO probability and VSS cross-section models
     for the following process: M(i) + P -> M(i + delta) + P
@@ -77,8 +79,14 @@ def raw_vt_rate(T: float, idata: np.ndarray, molecule_vibr_array: np.ndarray, mo
     ----------
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    beta : float
+        the IPL :math:`\\beta` parameter
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     molecule_vibr_array : 1-D array-like
         the array of vibrational energies of the molecule undergoing the VT transition
     molecule_vibr_zero : float
@@ -96,10 +104,12 @@ def raw_vt_rate(T: float, idata: np.ndarray, molecule_vibr_array: np.ndarray, mo
         The VT transition rate
 
     """
-    return 8.0 * raw_vt_integral(T, 0, idata, molecule_vibr_array, molecule_vibr_zero, molecule_diss, i, delta, False)
+    return 8.0 * raw_vt_integral(T, 0, mass, beta, vssc, vsso, molecule_vibr_array,
+                                 molecule_vibr_zero, molecule_diss, i, delta, False)
 
 
-def raw_vv_rate(T: float, idata: np.ndarray, molecule_vibr_array1: np.ndarray, molecule_vibr_array2: np.ndarray,
+def raw_vv_rate(T: float, mass: float, beta: float, vssc: float, vsso: float,
+                molecule_vibr_array1: np.ndarray, molecule_vibr_array2: np.ndarray,
                 i: int, k: int, i_delta: int):
     """Calculates the VV transition rate using the FHO probability and VSS cross-section models
     for the following process: M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)
@@ -108,8 +118,14 @@ def raw_vv_rate(T: float, idata: np.ndarray, molecule_vibr_array1: np.ndarray, m
     ----------
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    beta : float
+        the IPL :math:`\\beta` parameter
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     molecule_vibr_array1 : 1-D array-like
         the array of vibrational energies of the molecule M1
     molecule_vibr_array2 : 1-D array-like
@@ -127,7 +143,8 @@ def raw_vv_rate(T: float, idata: np.ndarray, molecule_vibr_array1: np.ndarray, m
         The VV transition rate
 
     """
-    return 8.0 * raw_vv_integral(T, 0, idata, molecule_vibr_array1, molecule_vibr_array2, i, k, i_delta, False)
+    return 8.0 * raw_vv_integral(T, 0, mass, beta, vssc, vsso,
+                                 molecule_vibr_array1, molecule_vibr_array2, i, k, i_delta, False)
 #
 #
 # def billing_nitrogen_vt_rate(T, name1, name2, i, i_delta):
